pub unsafe extern "C" fn OH_ResourceManager_GetRawFileDescriptorData(
rawFile: *const RawFile,
descriptor: *mut RawFileDescriptor,
) -> boolExpand description
@brief Obtains the file descriptor of a raw file based on the long offset and file length.
The obtains raw file descriptor is used to read the raw file.
@param rawFile Indicates the pointer to {@link RawFile}. @param descriptor Indicates the raw file’s file descriptor, start position and the length in the HAP. @return Returns true: obtains the raw file descriptor successfully, false: the raw file is not allowed to access. @since 12 @version 1.0