#[repr(C)]pub struct RawFileDescriptor {
pub fd: c_int,
pub start: c_long,
pub length: c_long,
}Expand description
@brief Represent the raw file descriptor’s info.
The RawFileDescriptor is an output parameter in the {@link OH_ResourceManager_GetRawFileDescriptor}, and describes the raw file’s file descriptor, start position and the length in the HAP.
@since 8 @version 1.0
Fields
fd: c_intthe raw file fd
start: c_longthe offset from where the raw file starts in the HAP
length: c_longthe length of the raw file in the HAP.