#[repr(C)]pub struct RawFileDescriptor64 {
pub fd: c_int,
pub start: i64,
pub length: i64,
}Expand description
@brief Represent the raw file descriptor’s info.
The RawFileDescriptor64 is an output parameter in the {@link OH_ResourceManager_GetRawFileDescriptor64}, and describes the raw file’s file descriptor, start position and the length in the HAP.
@since 11 @version 1.0
Fields
fd: c_intthe raw file fd
start: i64the offset from where the raw file starts in the HAP
length: i64the length of the raw file in the HAP.